@@ -4,7 +4,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.6';
+our $VERSION = '1.7';
 our $Debug   = 0;
 
 use LWP::UserAgent ();
@@ -36,7 +36,7 @@ sub new {
     $lwp_callback {$self} = $args{LWP_Callback} || undef;
     $utf8         {$self} = $args{utf8}         || undef;
     $space        {$self} = $args{Space}        || $ENV{SIGNALWIRE_SPACE};
-    $domain       {$self} = $args{Domain}       || '.signalwire.com';
+    $domain       {$self} = $args{Domain}       || 'signalwire.com';
 
     croak 'AccountSid and AuthToken are required'
 	unless $account_sid{$self} and $auth_token{$self};
@@ -76,7 +76,7 @@ sub _do_request {
     $lwp->agent("SignalWire-RestAPI/$VERSION");
 
     my $method = delete $args{METHOD};
-    my $url    = 'https://' . $space{$self} . $domain{$self} ."/" . $api_version{$self};
+    my $url    = 'https://' . $space{$self} . '.' . $domain{$self} . '/' . $api_version{$self};
     my $api    = delete $args{API} || '';
 
     if ($api_version{$self} eq 'api/laml/2010-04-01') {
@@ -331,7 +331,7 @@ document like this, telling us that everything went great:
       <DateUpdated>Wed, 10 Aug 2011 04:38:16 +0000</DateUpdated>
       <ParentCallSid/>
       <AccountSid>ACxxxxxxxx</AccountSid>
-      <To>+1.658675309</To>
+      <To>+15558675309</To>
       <ToFormatted>(555) 867-5309</ToFormatted>
       <From>+14158675309</From>
       <FromFormatted>(415) 867-5309</FromFormatted>
@@ -509,7 +509,7 @@ which now prints:
       <DateUpdated>Wed, 10 Aug 2011 04:38:16 +0000</DateUpdated>
       <ParentCallSid/>
       <AccountSid>ACxxxxxxxx</AccountSid>
-      <To>+1.658675309</To>
+      <To>+15558675309</To>
       <ToFormatted>(555) 867-5309</ToFormatted>
       <From>+13126540987</From>
       <FromFormatted>(312) 654-0987</FromFormatted>
@@ -847,7 +847,7 @@ Same as B<GET>.
 
 Example:
 
-  $response = $signalwire->DELETE('Recordings/RE41331862605f3d662488fdafda2e1.6f');
+  $response = $signalwire->DELETE('Recordings/RE41331862605f3d662488fdafda2e175f');
 
 =head1 API CHANGES
 
